@@ -73,7 +73,7 @@ SgLclGRtTAfPQLs0TjvgDft/f/LX85s0Pbu/sSDtdCLW5nTqDhSYM33sgUxPz1V5cc7/x/Mfr27y\
 
 #define TEST_AUTH_RESPONSE "https://www.facebook.com/connect/login_success.html#access_token=133410120012716|2.Y417pjPZqMDUtb408DykaQ__.86400.1297656000-100001502212382|B4s6Bi6D4Qn1E87pmi4MTyiFDG8&expires_in=87757"
 
-#define AUTH_URL "https://graph.facebook.com/oauth/authorize?client_id=133410120012716&redirect_uri=https://www.facebook.com/connect/login_success.html&type=user_agent&display=touch&scope=user_birthday,friends_birthday,user_photos,friends_photos,user_location,friends_location,user_relationships,friends_relationships,user_religion_politics,friends_religion_politics,publish_stream,user_online_presence,user_about_me,user_education_history,friends_education_history,user_status,friends_status,user_religion_politics,friends_religion_politics,user_about_me,friends_about_me,user_hometown,friends_hometown,read_mailbox"
+#define AUTH_URL "https://graph.facebook.com/oauth/authorize?client_id=133410120012716&redirect_uri=https://www.facebook.com/connect/login_success.html&type=user_agent&display=touch&scope=user_birthday,friends_birthday,user_photos,friends_photos,user_location,friends_location,user_relationships,friends_relationships,user_religion_politics,friends_religion_politics,publish_stream,user_online_presence,user_about_me,user_education_history,friends_education_history,user_status,friends_status,user_religion_politics,friends_religion_politics,user_about_me,friends_about_me,user_hometown,friends_hometown,read_mailbox,user_photo_video_tags,friends_photo_video_tags"
 
 #define LOGIN_SUCCESS "^http[s]{,1}://www\\.facebook\\.com/connect/login_success\\.html.*"
 
